# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['altair_recipes']

package_data = \
{'': ['*']}

install_requires = \
['altair>=4.0.0,<5.0.0',
 'attrs>=19.2,<20.0',
 'autosig>=0.10.0',
 'boltons>=19.1.0',
 'numpy>=1.17.0',
 'pandas>=0.25.0',
 'requests>=2.22.0',
 'toolz>=0.10.0']

extras_require = \
{'pweave': ['ipython>=7.16.3,<8.0.0']}

setup_kwargs = {
    'name': 'altair-recipes',
    'version': '0.9.1',
    'description': 'A collection of ready-made statistical graphics for vega',
    'long_description': '\nIntroduction to altair_recipes\n==============================\n\n\n.. image:: https://img.shields.io/pypi/v/altair_recipes.svg\n        :target: https://pypi.python.org/pypi/altair_recipes\n        :alt: Version\n\n.. image:: https://codecov.io/gh/piccolbo/altair_recipes/graph/badge.svg\n        :target: https://codecov.io/gh/piccolbo/altair_recipes\n        :alt: Code Coverage\n\n.. image:: https://readthedocs.org/projects/altair_recipes/badge/?version=latest\n        :target: https://altair_recipes.readthedocs.io/en/latest/?badge=latest\n        :alt: Documentation Status\n\n\n.. image:: https://pyup.io/repos/github/piccolbo/altair_recipes/shield.svg\n     :target: https://pyup.io/repos/github/piccolbo/altair_recipes/\n     :alt: Updates\n\n.. image:: https://api.codeclimate.com/v1/badges/4ab3f4aad65b12b2bb7c/maintainability\n     :target: https://codeclimate.com/github/piccolbo/altair_recipes/maintainability\n     :alt: Maintainability\n\n\nA collection of ready-made statistical graphics for vega.\n---------------------------------------------------------\n\n``vega`` is a statistical graphics system for the web, meaning the plots are displayed in a browser. As an added bonus, it adds interactions, again through web technologies: select data point, reveal information on hover etc. Interaction and the web are clearly the future of statistical graphics. Even the successor to the famous ``ggplot`` for R, ``ggvis`` is based on ``vega``.\n\n``altair`` is a python package that produces ``vega`` graphics. Like ``vega``, it adopts an approach to describing statistical graphics known as *grammar of graphics* which underlies other well known packages such as ``ggplot`` for R. It represents a extremely useful compromise of power and flexibility. Its elements are data, marks (points, lines), encodings (relations between data and marks), scales etc.\n\nSometimes we want to skip all of that and just produce a boxplot (or heatmap or histogram, the argument is the same) by calling::\n\n  boxplot(data.iris(), columns="petalLength", group_by="species")\n\nbecause:\n\n\n* It\'s a well known type of statistical graphics that everyone can recognize and understand on the fly.\n* Creativity is nice, in statistical graphics as in many other endeavors, but dangerous: there are more `bad charts <https://www.google.com/search?q=chartjunk&tbm=isch>`_ out there than good ones. The *grammar of graphics* is no insurance.\n* While it\'s simple to put together a boxplot in ``altair``, it isn\'t trivial: there are rectangles, vertical lines, horizontal lines (whiskers), points (outliers). Each element is related to a different statistics of the data. It\'s about `30 lines of code <https://altair-viz.github.io/gallery/boxplot_max_min.html>`_ and, unless you run them, it\'s hard to tell you are looking at a boxplot.\n* One doesn\'t always need the control that the grammar of graphics affords. There are times when I need to see a boxplot as quick as possible. Others, for instance preparing a publication, when I need to control every detail.\n\nThe boxplot is not the only example. The scatterplot, the quantile-quantile plot, the heatmap are important idioms that are battle tested in data analysis practice. They deserve their own abstraction. Other packages offering an abstraction above the grammar level are:\n\n* ``seaborn`` and the graphical subset of ``pandas``, for example, both provide high level statistical graphics primitives (higher than the grammar of graphics) and they are quite successful (but not web-based).\n* ``ggplot``, even if named after the Grammar of Graphics, slipped in some more complex charts, pretending they are elements of the grammar, such as ``geom_boxplot``, because sometimes even R developers are lazy. But a boxplot is not a *geom* or mark. It\'s a combination of several ones, certain statistics and so on. I suspect the authors of ``altair`` know better than mixing the two levels.\n\n\n``altair_recipes`` aims to fill this space above ``altair`` while making full use of its features. It provides a growing list of "classic" statistical graphics without going down to the grammar level. At the same time it is hoped that, over time, it can become  a repository of examples and model best practices for ``altair``, a computable form of its `gallery <https://altair-viz.github.io/gallery/index.html>`_.\n\nThere is *one more thing*. It\'s nice to have all these famous chart types available at a stroke of the keyboard, but we still have to decide which type of graphics to use and, in certain cases, the association between variables in the data and channels in the graphics (what becomes coordinate, what becomes color etc.). It still is work and things can still go wrong, sometimes in subtle ways. Enter ``autoplot``. ``autoplot`` inspects the data, selects a suitable graphics and generates it. While no claim is made that the result is optimal, it will make reasonable choices and avoid common pitfalls, like `overlapping points <https://liorpachter.files.wordpress.com/2017/08/animerr.gif?w=490>`_ in scatterplots. While there are interesting `research efforts <https://github.com/uwdata/draco>`_ aimed at characterizing the optimal graphics for a given data set, their goal is more ambitious than just selecting from a repertoire of pre-defined graphics types and they are fairly complex. Therefore, at this time ``autoplot`` is based on a set of reasonable heuristics derived from decades of experience such as:\n\n* use stripplot and scatterplot to display continuous data, barcharts for discrete data\n* use opacity to counter mark overlap, but not with discrete color maps\n* switch to summaries (count and averages) when the amount of overlap is too high\n* use facets for discrete data\n\n``autoplot`` is work in progress and perhaps will always be and feedback is most welcome. A large number of charts generated with it is available at the end of the Examples_ page and should give a good idea of what it does. In particular, in this first iteration we do not make any attempt to detect if a dataset represents a function or a relation, hence scatterplots are preferred over line plots. Moreover there is no special support for evenly spaced data, such as a time series.\n\nFeatures\n--------\n\n* Free software: BSD license.\n* Fully documented_.\n* Highly consistent API enforced with autosig_\n* Near 100% regression test coverage.\n* Support for dataframe and vector inputs\n* Support for both wide and long dataframe formats.\n* Data can be provided as a dataframe or as a URL pointing to a csv or json file.\n* All charts produced are valid ``altair`` charts, can be modified, combined, saved, served, embedded exactly as one.\n\n\nChart types\n-----------\n\n* autocorrelation\n* barchart\n* boxplot\n* heatmap\n* histogram, in a simple and multi-variable version\n* qqplot\n* scatterplot in the simple and all-vs-all versions\n* smoother, smoothing line with IRQ range shading\n* stripplot\n\nSee Examples_.\n\n\n.. _Examples: https://altair-recipes.readthedocs.io/en/latest/examples.html\n.. _autosig: http://github.com/piccolbo/autosig\n.. _documented: https://altair_recipes.readthedocs.io\n',
    'author': 'Antonio Piccolboni',
    'author_email': 'antonio@piccolboni.info',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/piccolbo/altair_recipes',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.8.0,<4.0.0',
}


setup(**setup_kwargs)
